@@ -8,24 +8,12 @@
  *          Jorn Baayen <jorn@openedhand.com>
  *          Krzesimir Nowak <krnowak@openismus.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GUPNP_DIDL_LITE_OBJECT_H__
-#define __GUPNP_DIDL_LITE_OBJECT_H__
+#ifndef GUPNP_DIDL_LITE_OBJECT_H
+#define GUPNP_DIDL_LITE_OBJECT_H
 
 #include <stdarg.h>
 #include <glib-object.h>
@@ -38,39 +26,18 @@
 
 G_BEGIN_DECLS
 
-GType
-gupnp_didl_lite_object_get_type (void) G_GNUC_CONST;
+G_DECLARE_DERIVABLE_TYPE(GUPnPDIDLLiteObject,
+                         gupnp_didl_lite_object,
+                         GUPNP,
+                         DIDL_LITE_OBJECT,
+                         GObject)
 
 #define GUPNP_TYPE_DIDL_LITE_OBJECT \
                 (gupnp_didl_lite_object_get_type ())
-#define GUPNP_DIDL_LITE_OBJECT(obj) \
-                (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
-                 GUPNP_TYPE_DIDL_LITE_OBJECT, \
-                 GUPnPDIDLLiteObject))
-#define GUPNP_DIDL_LITE_OBJECT_CLASS(obj) \
-                (G_TYPE_CHECK_CLASS_CAST ((obj), \
-                 GUPNP_TYPE_DIDL_LITE_OBJECT, \
-                 GUPnPDIDLLiteObjectClass))
-#define GUPNP_IS_DIDL_LITE_OBJECT(obj) \
-                (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
-                 GUPNP_TYPE_DIDL_LITE_OBJECT))
-#define GUPNP_IS_DIDL_LITE_OBJECT_CLASS(obj) \
-                (G_TYPE_CHECK_CLASS_TYPE ((obj), \
-                 GUPNP_TYPE_DIDL_LITE_OBJECT))
-#define GUPNP_DIDL_LITE_OBJECT_GET_CLASS(obj) \
-                (G_TYPE_INSTANCE_GET_CLASS ((obj), \
-                 GUPNP_TYPE_DIDL_LITE_OBJECT, \
-                 GUPnPDIDLLiteObjectClass))
 
 typedef struct _GUPnPDIDLLiteObjectPrivate GUPnPDIDLLiteObjectPrivate;
 
-typedef struct {
-        GObject parent;
-
-        GUPnPDIDLLiteObjectPrivate *priv;
-} GUPnPDIDLLiteObject;
-
-typedef struct {
+struct _GUPnPDIDLLiteObjectClass {
         GObjectClass parent_class;
 
         /* future padding */
@@ -78,7 +45,7 @@ typedef struct {
         void (* _gupnp_reserved2) (void);
         void (* _gupnp_reserved3) (void);
         void (* _gupnp_reserved4) (void);
-} GUPnPDIDLLiteObjectClass;
+};
 
 xmlNode *
 gupnp_didl_lite_object_get_xml_node     (GUPnPDIDLLiteObject *object);
@@ -310,6 +277,9 @@ gupnp_didl_lite_object_apply_fragments
 char *
 gupnp_didl_lite_object_get_xml_string   (GUPnPDIDLLiteObject *object);
 
+char *
+gupnp_format_date_time_for_didl_lite (GDateTime *date_time, gboolean date_only);
+
 G_END_DECLS
 
 #endif /* __GUPNP_DIDL_LITE_OBJECT_H__ */
