@@ -5,22 +5,12 @@
  * Author: Jens Georg <jensg@openismus.com>
  *         Jens Georg <mail@jensge.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
+#include <config.h>
+
 #include <string.h>
 
 #include <libgupnp-av/gupnp-media-collection.h>
@@ -469,9 +459,6 @@ test_didl_collection_create_reparent (void)
 
 int main (int argc, char *argv[])
 {
-#if !GLIB_CHECK_VERSION (2, 35, 0)
-        g_type_init ();
-#endif
         g_test_init (&argc, &argv, NULL);
 
         g_test_add_func ("/didl/collection/construction",
